import * as sfn from '../../aws-stepfunctions';
import { Construct } from 'constructs';
import { RestApi, RestApiProps } from '.';
import { RequestContext } from './integrations';
/**
 * (experimental) Properties for StepFunctionsRestApi.
 *
 * @experimental
 */
export interface StepFunctionsRestApiProps extends RestApiProps {
    /**
     * (experimental) The default State Machine that handles all requests from this API.
     *
     * This stateMachine will be used as a the default integration for all methods in
     * this API, unless specified otherwise in `addMethod`.
     *
     * @experimental
     */
    readonly stateMachine: sfn.IStateMachine;
    /**
     * (experimental) Which details of the incoming request must be passed onto the underlying state machine, such as, account id, user identity, request id, etc.
     *
     * The execution input will include a new key `requestContext`:
     *
     * {
     *    "body": {},
     *    "requestContext": {
     *        "key": "value"
     *    }
     * }
     *
     * @default - all parameters within request context will be set as false
     * @experimental
     */
    readonly requestContext?: RequestContext;
    /**
     * (experimental) Check if querystring is to be included inside the execution input.
     *
     * The execution input will include a new key `queryString`:
     *
     * {
     *    "body": {},
     *    "querystring": {
     *      "key": "value"
     *    }
     * }
     *
     * @default true
     * @experimental
     */
    readonly querystring?: boolean;
    /**
     * (experimental) Check if path is to be included inside the execution input.
     *
     * The execution input will include a new key `path`:
     *
     * {
     *    "body": {},
     *    "path": {
     *      "resourceName": "resourceValue"
     *    }
     * }
     *
     * @default true
     * @experimental
     */
    readonly path?: boolean;
    /**
     * (experimental) Check if header is to be included inside the execution input.
     *
     * The execution input will include a new key `headers`:
     *
     * {
     *    "body": {},
     *    "headers": {
     *       "header1": "value",
     *       "header2": "value"
     *    }
     * }
     *
     * @default false
     * @experimental
     */
    readonly headers?: boolean;
}
/**
 * (experimental) Defines an API Gateway REST API with a Synchrounous Express State Machine as a proxy integration.
 *
 * @experimental
 */
export declare class StepFunctionsRestApi extends RestApi {
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: StepFunctionsRestApiProps);
}
