import * as assets from '../../aws-s3-assets';
import { Construct } from 'constructs';
import { CfnRepository } from './codecommit.generated';
/**
 * (experimental) Represents the structure to pass into the underlying CfnRepository class.
 *
 * @experimental
 */
export interface CodeConfig {
    /**
     * (experimental) represents the underlying code structure.
     *
     * @experimental
     */
    readonly code: CfnRepository.CodeProperty;
}
/**
 * (experimental) Represents the contents to initialize the repository with.
 *
 * @experimental
 */
export declare abstract class Code {
    /**
     * (experimental) Code from directory.
     *
     * @param directoryPath the path to the local directory containing the contents to initialize the repository with.
     * @param branch the name of the branch to create in the repository.
     * @experimental
     */
    static fromDirectory(directoryPath: string, branch?: string): Code;
    /**
     * (experimental) Code from preexisting ZIP file.
     *
     * @param filePath the path to the local ZIP file containing the contents to initialize the repository with.
     * @param branch the name of the branch to create in the repository.
     * @experimental
     */
    static fromZipFile(filePath: string, branch?: string): Code;
    /**
     * (experimental) Code from user-supplied asset.
     *
     * @param asset pre-existing asset.
     * @param branch the name of the branch to create in the repository.
     * @experimental
     */
    static fromAsset(asset: assets.Asset, branch?: string): Code;
    /**
     * (experimental) This method is called after a repository is passed this instance of Code in its 'code' property.
     *
     * @param scope the binding scope.
     * @experimental
     */
    abstract bind(scope: Construct): CodeConfig;
}
