import * as iam from '../../aws-iam';
import { NestedStack, IConstruct } from '../../core';
import { Construct } from 'constructs';
import { ICluster } from './cluster';
/**
 * (experimental) Kubectl Provider Properties.
 *
 * @experimental
 */
export interface KubectlProviderProps {
    /**
     * (experimental) The cluster to control.
     *
     * @experimental
     */
    readonly cluster: ICluster;
}
/**
 * (experimental) Kubectl Provider Attributes.
 *
 * @experimental
 */
export interface KubectlProviderAttributes {
    /**
     * (experimental) The kubectl provider lambda arn.
     *
     * @experimental
     */
    readonly functionArn: string;
    /**
     * (experimental) The IAM role to assume in order to perform kubectl operations against this cluster.
     *
     * @experimental
     */
    readonly kubectlRoleArn: string;
    /**
     * (experimental) The IAM execution role of the handler.
     *
     * This role must be able to assume kubectlRoleArn
     *
     * @experimental
     */
    readonly handlerRole: iam.IRole;
}
/**
 * (experimental) Imported KubectlProvider that can be used in place of the default one created by CDK.
 *
 * @experimental
 */
export interface IKubectlProvider extends IConstruct {
    /**
     * (experimental) The custom resource provider's service token.
     *
     * @experimental
     */
    readonly serviceToken: string;
    /**
     * (experimental) The IAM role to assume in order to perform kubectl operations against this cluster.
     *
     * @experimental
     */
    readonly roleArn: string;
    /**
     * (experimental) The IAM execution role of the handler.
     *
     * @experimental
     */
    readonly handlerRole: iam.IRole;
}
/**
 * (experimental) Implementation of Kubectl Lambda.
 *
 * @experimental
 */
export declare class KubectlProvider extends NestedStack implements IKubectlProvider {
    /**
     * (experimental) Take existing provider or create new based on cluster.
     *
     * @param scope Construct.
     * @param cluster k8s cluster.
     * @experimental
     */
    static getOrCreate(scope: Construct, cluster: ICluster): IKubectlProvider;
    /**
     * (experimental) Import an existing provider.
     *
     * @param scope Construct.
     * @param id an id of resource.
     * @param attrs attributes for the provider.
     * @experimental
     */
    static fromKubectlProviderAttributes(scope: Construct, id: string, attrs: KubectlProviderAttributes): IKubectlProvider;
    /**
     * (experimental) The custom resource provider's service token.
     *
     * @experimental
     */
    readonly serviceToken: string;
    /**
     * (experimental) The IAM role to assume in order to perform kubectl operations against this cluster.
     *
     * @experimental
     */
    readonly roleArn: string;
    /**
     * (experimental) The IAM execution role of the handler.
     *
     * @experimental
     */
    readonly handlerRole: iam.IRole;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: KubectlProviderProps);
}
