import { PolicyDocument, PolicyStatement } from '../../aws-iam';
import { Resource } from '../../core';
import { Construct } from 'constructs';
/**
 * (experimental) Properties to define Cloudwatch log group resource policy.
 *
 * @experimental
 */
export interface ResourcePolicyProps {
    /**
     * (experimental) Name of the log group resource policy.
     *
     * @default - Uses a unique id based on the construct path
     * @experimental
     */
    readonly resourcePolicyName?: string;
    /**
     * (experimental) Initial statements to add to the resource policy.
     *
     * @default - No statements
     * @experimental
     */
    readonly policyStatements?: PolicyStatement[];
}
/**
 * (experimental) Resource Policy for CloudWatch Log Groups.
 *
 * Policies define the operations that are allowed on this resource.
 *
 * You almost never need to define this construct directly.
 *
 * All AWS resources that support resource policies have a method called
 * `addToResourcePolicy()`, which will automatically create a new resource
 * policy if one doesn't exist yet, otherwise it will add to the existing
 * policy.
 *
 * Prefer to use `addToResourcePolicy()` instead.
 *
 * @experimental
 */
export declare class ResourcePolicy extends Resource {
    /**
     * (experimental) The IAM policy document for this resource policy.
     *
     * @experimental
     */
    readonly document: PolicyDocument;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props?: ResourcePolicyProps);
}
