import * as iam from '../../aws-iam';
import { Resource } from '../../core';
import { Construct } from 'constructs';
import { ISecret } from './secret';
/**
 * (experimental) Construction properties for a ResourcePolicy.
 *
 * @experimental
 */
export interface ResourcePolicyProps {
    /**
     * (experimental) The secret to attach a resource-based permissions policy.
     *
     * @experimental
     */
    readonly secret: ISecret;
}
/**
 * (experimental) Resource Policy for SecretsManager Secrets.
 *
 * Policies define the operations that are allowed on this resource.
 *
 * You almost never need to define this construct directly.
 *
 * All AWS resources that support resource policies have a method called
 * `addToResourcePolicy()`, which will automatically create a new resource
 * policy if one doesn't exist yet, otherwise it will add to the existing
 * policy.
 *
 * Prefer to use `addToResourcePolicy()` instead.
 *
 * @experimental
 */
export declare class ResourcePolicy extends Resource {
    /**
     * (experimental) The IAM policy document for this policy.
     *
     * @experimental
     */
    readonly document: iam.PolicyDocument;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: ResourcePolicyProps);
}
