import * as eks from '../../../aws-eks';
import * as iam from '../../../aws-iam';
import * as sfn from '../../../aws-stepfunctions';
import { Construct } from 'constructs';
/**
 * (experimental) Class that supports methods which return the EKS cluster name depending on input type.
 *
 * @experimental
 */
export declare class EksClusterInput {
    readonly clusterName: string;
    /**
     * (experimental) Specify an existing EKS Cluster as the name for this Cluster.
     *
     * @experimental
     */
    static fromCluster(cluster: eks.ICluster): EksClusterInput;
    /**
     * (experimental) Specify a Task Input as the name for this Cluster.
     *
     * @experimental
     */
    static fromTaskInput(taskInput: sfn.TaskInput): EksClusterInput;
    /**
     * Initializes the clusterName
     *
     * @param clusterName The name of the EKS Cluster
     */
    private constructor();
}
/**
 * (experimental) Properties to define a EMR Containers CreateVirtualCluster Task on an EKS cluster.
 *
 * @experimental
 */
export interface EmrContainersCreateVirtualClusterProps extends sfn.TaskStateBaseProps {
    /**
     * (experimental) EKS Cluster or task input that contains the name of the cluster.
     *
     * @experimental
     */
    readonly eksCluster: EksClusterInput;
    /**
     * (experimental) The namespace of an EKS cluster.
     *
     * @default - 'default'
     * @experimental
     */
    readonly eksNamespace?: string;
    /**
     * (experimental) Name of the virtual cluster that will be created.
     *
     * @default - the name of the state machine execution that runs this task and state name
     * @experimental
     */
    readonly virtualClusterName?: string;
    /**
     * (experimental) The tags assigned to the virtual cluster.
     *
     * @default {}
     * @experimental
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * (experimental) Task that creates an EMR Containers virtual cluster from an EKS cluster.
 *
 * @see https://docs.aws.amazon.com/step-functions/latest/dg/connect-emr-eks.html
 * @experimental
 */
export declare class EmrContainersCreateVirtualCluster extends sfn.TaskStateBase {
    private readonly props;
    private static readonly SUPPORTED_INTEGRATION_PATTERNS;
    /**
     * @experimental
     */
    protected readonly taskMetrics?: sfn.TaskMetricsConfig;
    /**
     * @experimental
     */
    protected readonly taskPolicies?: iam.PolicyStatement[];
    private readonly integrationPattern;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: EmrContainersCreateVirtualClusterProps);
    /**
     * @internal
     */
    protected _renderTask(): any;
    private createPolicyStatements;
}
